import seaborn as sns
import matplotlib.pyplot as plt
import matplotlib.colors as mcolors


from .palettes import PALETTES


color2rgb = mcolors.ColorConverter().to_rgb


def register_cmap(name=None):
    palettes_list = PALETTES.items()
    if name in PALETTES:
        palettes_list = [(name, PALETTES[name])]

    for name, colors in palettes_list:
        cmap = mcolors.ListedColormap(list(map(color2rgb, colors.values())), name=name)
        plt.register_cmap(cmap=cmap)



import json
from pathlib import Path
from setuptools import setup, find_packages


BASE_DIR = Path(__file__).resolve().parent
version_info = json.loads(BASE_DIR.joinpath('sci_palettes', 'version.json').read_text())

setup(
    name=version_info['prog'],
    version=version_info['version'],
    author=version_info['author'],
    author_email=version_info['author_email'],
    description=version_info['desc'],
    long_description=BASE_DIR.joinpath('README.md').read_text(),
    long_description_content_type="text/markdown",
    license='BSD License',
    install_requires=BASE_DIR.joinpath('requirements.txt').read_text().strip().split(),
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries'
    ]
)
